@@ -25,6 +25,7 @@ along with NCLua.  If not, see <http://www.gnu.org/licenses/>.  */
 
 #include <cairo.h>
 #include <glib.h>
+#include <glib-object.h>
 #include <pango/pangocairo.h>
 
 #if HAVE_GTK
@@ -1658,6 +1659,7 @@ int luaopen_nclua_canvas (lua_State *L);
 int
 luaopen_nclua_canvas (lua_State *L)
 {
+  G_TYPE_INIT_WRAPPER ();
   luax_newmetatable (L, CANVAS);
   luaL_setfuncs (L, funcs, 0);
   return 1;
