@@ -23,6 +23,7 @@ along with NCLua.  If not, see <http://www.gnu.org/licenses/>.  */
 #include <lauxlib.h>
 
 #include <glib.h>
+#include <glib-object.h>
 #include <gio/gio.h>
 
 #include "macros.h"
@@ -697,6 +698,7 @@ int luaopen_nclua_event_socket (lua_State *L);
 int
 luaopen_nclua_event_socket (lua_State *L)
 {
+  G_TYPE_INIT_WRAPPER ();
   socket_init_registry (L);
   luax_newmetatable (L, SOCKET);
   luaL_setfuncs (L, socket_funcs, 0);
